pub fn red<T>(text: &T) -> impl Display + '_where
T: Display + OwoColorize,Expand description
Color the text red if the stream supports color.
pub fn red<T>(text: &T) -> impl Display + '_where
T: Display + OwoColorize,Color the text red if the stream supports color.