pub fn yellow<T>(text: &T) -> impl Display + '_where
T: Display + OwoColorize,Expand description
Color the text yellow if the stream supports color.
pub fn yellow<T>(text: &T) -> impl Display + '_where
T: Display + OwoColorize,Color the text yellow if the stream supports color.