pub struct ErrorData {
pub severity: Severity,
pub message: String,
pub src: Option<String>,
pub labels: Option<Vec<Label>>,
pub help: Option<String>,
pub source_error: Option<Box<Error>>,
pub code: Option<String>,
pub details: Option<String>,
pub stack: Option<String>,
pub hide_stack: Option<bool>,
}Expand description
Core error type.
See the test case for specific usage.
Fields
severity: SeverityError severity.
message: StringMessage.
src: Option<String>Source code.
labels: Option<Vec<Label>>Labels displayed in source code.
The source code block will be displayed only if both source code and labels exist.
help: Option<String>Help text.
source_error: Option<Box<Error>>Source error.
code: Option<String>Error Code.
This field is used to distinguish error types and will not be used for error display.
details: Option<String>Detail info.
This field is used to save extra info when hide stack and will not be used for error display. TODO: remove this field and hide stack, just use stack field.
stack: Option<String>Error stack.
hide_stack: Option<bool>Whether to hide the stack.
TODO: replace Option